@@ -1,3 +1,5 @@
+if (!require ("stats", quietly=TRUE))
+    stop("package", sQuote("stats"), "is needed.  Stopping")
 camp <- ts(c(
  37., 60., 71., 55., 53., 78., 53., 34., 54., 66., 63., 64., 81., 83., 82., 67., 61., 63.,        
  45., 71., 67., 47., 47., 45., 59., 58., 68., 65., 74., 48., 22., 48., 40., 45., 33., 50.,        
